@@ -385,8 +385,8 @@ class Config(ConfigStructured):
             'H' - Hours. Same possible values as in freq."""
             return []
 
-        @MyProperty(options=("sum", "mean", None))
-        def resample_function() -> Union[str, bool]:
+        @MyProperty(options=("sum", "mean", "", None))
+        def resample_function() -> Union[str, None]:
             """
             Options:
                 'sum', 'mean', None
